@@ -140,10 +140,7 @@ def filter_bed_file_by_(bed_file_1, bed_file_2, output_file):
     bed_file_1_bedtool_intersect_bed_file_2_bedtool = bed_file_1_bedtool.intersect(bed_file_2_bedtool, v = True)
     bed_file_1_bedtool_intersect_bed_file_2_bedtool.saveas(output_file)
 
-def filter_df_by_tfactor_fastas(df, folder, derive_target_col = False):
-    if derive_target_col:
-        df = remap_df_add_experiment_target_cell(df)
-
+def filter_df_by_tfactor_fastas(df, folder):
     files = [*Path(folder).glob('**/*.fasta')]
     present_target_names = set([f.stem.split('.')[0] for f in files])
     all_df_targets = df.get_column('target').unique().to_list()
@@ -224,7 +221,7 @@ class RemapAllPeakDataset(Dataset):
             dataset_chr_ids = dataset_chr_ids.intersection(set(filter_chromosome_ids))
 
         remap_df = remap_df.filter(pl_isin('column_1', get_chr_names(dataset_chr_ids)))
-        remap_df = filter_df_by_tfactor_fastas(remap_df, factor_fasta_folder, derive_target_col = True)
+        remap_df = filter_df_by_tfactor_fastas(remap_df, factor_fasta_folder)
 
         self.factor_ds = FactorProteinDataset(factor_fasta_folder)
 
@@ -306,7 +303,7 @@ class NegativePeakDataset(Dataset):
 
         # filter remap dataframe
 
-        remap_df = filter_df_by_tfactor_fastas(remap_df, factor_fasta_folder, derive_target_col = True)
+        remap_df = filter_df_by_tfactor_fastas(remap_df, factor_fasta_folder)
 
         dataset_chr_ids = CHR_IDS
 
